@@ -4,4 +4,5 @@ plan skip_all => "We just want to skip";
 
 test 'just fail' => sub { ok(0) };
 
-run_tests;
+run_me;
+done_testing;
